==> scijava-expression-parser-2.1.1-sources.jar: org/scijava/sjep/Tokens.java <==
/*
 * #%L
 * SciJava mathematical expression parser.
 * %%
 * Copyright (C) 2015 Board of Regents of the University of
 * Wisconsin-Madison.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * #L%
 */

package org.scijava.sjep;

/**
 * Utility methods for working with tokens.
 *
 * @author Curtis Rueden
 */
public final class Tokens {

	private Tokens() {
		// NB: Prevent instantiation of utility class.
	}

	public static boolean isNumber(final Object o) {
		return o instanceof Number;
	}

	public static boolean isFunction(final Object o) {
		return o instanceof Function;
	}

	public static boolean isVariable(final Object o) {
		return o instanceof Variable;
	}

	public static boolean isOperator(final Object o) {
		return o instanceof Operator;
	}

	public static boolean isVerb(final Object o) {
		return o instanceof Verb;
	}

	public static boolean isComma(final Object o) {
		return isCharacter(o, ',');
	}

	public static boolean isParen(final Object o) {
		return isLeftParen(o) || isRightParen(o);
	}

	public static boolean isLeftParen(final Object o) {
		return isCharacter(o, '(');
	}

	public static boolean isRightParen(final Object o) {
		return isCharacter(o, ')');
	}

	public static boolean isCharacter(final Object o, final Character c) {
		return o instanceof Character && ((Character) o).equals(c);
	}

}

==> scijava-expression-parser-3.0.1-sources.jar: org/scijava/sjep/Tokens.java <==
/*
 * #%L
 * SciJava mathematical expression parser.
 * %%
 * Copyright (C) 2015 - 2016 Board of Regents of the University of
 * Wisconsin-Madison.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * #L%
 */

package org.scijava.sjep;

/**
 * Utility methods for working with tokens.
 *
 * @author Curtis Rueden
 */
public final class Tokens {

	private Tokens() {
		// NB: Prevent instantiation of utility class.
	}

	public static boolean isNumber(final Object o) {
		return o instanceof Number;
	}

	public static boolean isGroup(final Object o) {
		return o instanceof Group;
	}

	public static boolean isVariable(final Object o) {
		return o instanceof Variable;
	}

	public static boolean isOperator(final Object o) {
		return o instanceof Operator;
	}

	public static boolean isComma(final Object o) {
		return isCharacter(o, ',');
	}

	public static boolean isCharacter(final Object o, final Character c) {
		return o instanceof Character && ((Character) o).equals(c);
	}

	public static boolean isMatchingGroup(final Object o, final Group g) {
		return isGroup(o) && ((Group) o).matches(g);
	}
}
